@@ -6,9 +6,6 @@ obs <- data[,2]
     if(save=="yes"){
       file<-file.choose(new=FALSE)
     }
-    if(save=="check"){
-      file<-fileName
-    }
     file.a<-tempfile(pattern="ascores",tmpdir=tempdir())
     file.b<-tempfile(pattern="bscores",tmpdir=tempdir())
     repeat{
@@ -68,9 +65,6 @@ obs <- data[,2]
     if(save=="yes"){
       file<-file.choose(new=FALSE)
     }
-    if(save=="check"){
-      file<-fileName
-    }
     file.a<-tempfile(pattern="ascores",tmpdir=tempdir())
     file.b<-tempfile(pattern="bscores",tmpdir=tempdir())
     MT<-nrow(data)
@@ -136,9 +130,6 @@ obs <- data[,2]
     if(save=="yes"){
       file<-file.choose(new=FALSE)
     }
-    if(save=="check"){
-      file<-fileName
-    }
     file.a<-tempfile(pattern="ascores",tmpdir=tempdir())
     file.b<-tempfile(pattern="bscores",tmpdir=tempdir())
     MT<-nrow(data)
@@ -219,9 +210,6 @@ obs <- data[,2]
     if(save=="yes"){
       file<-file.choose(new=FALSE)
     }
-    if(save=="check"){
-      file<-fileName
-    }
     observed<-data[,2]
     MT<-nrow(data)
     quantity<-choose(MT-2*limit+1,1)
@@ -269,9 +257,6 @@ obs <- data[,2]
     if(save=="yes"){
       file<-file.choose(new=FALSE)
     }
-    if(save=="check"){
-      file<-fileName
-    }
     observed<-data[,2]
     MT<-nrow(data)
     quantity<-choose(MT-3*limit+2,2)
@@ -400,9 +385,6 @@ obs <- data[,2]
     if(save=="yes"){
       file<-file.choose(new=FALSE)
     }
-    if(save=="check"){
-      file<-fileName
-    }
     observed<-data[,2]
     MT<-nrow(data)
     quantity<-choose(MT-4*limit+3,3)
@@ -641,17 +623,14 @@ obs <- data[,2]
     if(save=="yes"){
       fileSAVE<-file.choose(new=FALSE)
     }
-    if(save=="check"){
-      fileSAVE<-fileName
-    }
     if(save=="yes"|save=="check"){
       write.table(distribution,file=fileSAVE,col.names=FALSE,row.names=FALSE,append=FALSE)
       return(distribution)
-      unlink(fileCOMBSTARTPOINTS,recursive=FALSE)
+      unlink(fileCOMBSTARTPTS,recursive=FALSE)
     }
     if(save=="no"){
       return(distribution)
-      unlink(fileCOMBSTARTPOINTS,recursive=FALSE)
+      unlink(fileCOMBSTARTPTS,recursive=FALSE)
     }
   }
 
