@@ -9,9 +9,6 @@ pvalue.systematic<-function(design,statistic,save="no",limit,data=read.table(fil
       if(save=="yes"){
         file<-file.choose(new=FALSE)
       }
-      if(save=="check"){
-        file<-fileName
-      }
       observed<-data[,2]
       scores.a<-combn(observed,MT/2)
       mean.a<-numeric(ncol(scores.a))
@@ -57,9 +54,6 @@ pvalue.systematic<-function(design,statistic,save="no",limit,data=read.table(fil
       if(save=="yes"){
         file<-file.choose(new=FALSE)
       }
-      if(save=="check"){
-        file<-fileName
-      }
       N<-c(rep("A",MT/2),rep("B",MT/2))
       assignment<-matrix(0,ncol=MT)
       assignment<-rbind(sample(N,MT,replace=FALSE))
@@ -146,9 +140,6 @@ pvalue.systematic<-function(design,statistic,save="no",limit,data=read.table(fil
     if(save=="yes"){
       file<-file.choose(new=FALSE)
     }
-    if(save=="check"){
-      file<-fileName
-    }
     observed1<-rbind(observed.a,observed.b)
     observed2<-rbind(observed.b,observed.a)
     scores.a<-numeric()
@@ -200,9 +191,6 @@ pvalue.systematic<-function(design,statistic,save="no",limit,data=read.table(fil
       if(save=="yes"){
         file<-file.choose(new=FALSE)
       }
-      if(save=="check"){
-        file<-fileName
-      }
       index<-1:MT
       index.a<-matrix(combn(index,(MT/2)),ncol=quantityCRD)
       index.b<-matrix(index.a[,ncol(index.a):1],ncol=quantityCRD)
@@ -304,9 +292,6 @@ pvalue.systematic<-function(design,statistic,save="no",limit,data=read.table(fil
       if(save=="yes"){
         file<-file.choose(new=FALSE)
       }
-      if(save=="check"){
-        file<-fileName
-      }
       N<-c(rep(0,MT/2),rep(1,MT/2))
       assignment<-matrix(0,ncol=MT)
       assignment<-rbind(rep(c(0,1),MT/2))
@@ -421,9 +406,6 @@ pvalue.systematic<-function(design,statistic,save="no",limit,data=read.table(fil
     if(save=="yes"){
       file<-file.choose(new=FALSE)
     }
-    if(save=="check"){
-      file<-fileName
-    }
     index.a<-limit:(MT-limit)
     scores.a<-list()
     for(it in 1:quantity){
@@ -479,9 +461,6 @@ pvalue.systematic<-function(design,statistic,save="no",limit,data=read.table(fil
     if(save=="yes"){
       file<-file.choose(new=FALSE)
     }
-    if(save=="check"){
-      file<-fileName
-    }
     index1<-1:(MT-3*limit+1)
     index2<-rev(index1)
     index.a<-numeric()
@@ -626,9 +605,6 @@ pvalue.systematic<-function(design,statistic,save="no",limit,data=read.table(fil
     if(save=="yes"){
       file<-file.choose(new=FALSE)
     }
-    if(save=="check"){
-      file<-fileName
-    }
     index1<-1:(MT-4*limit+1)
     index2<-rev(cumsum(index1))
     index.a1<-numeric()
@@ -986,9 +962,6 @@ pvalue.systematic<-function(design,statistic,save="no",limit,data=read.table(fil
     if(save=="yes"){
       fileSAVE<-file.choose(new=FALSE)
     }
-    if(save=="check"){
-      fileSAVE<-fileName
-    }
     if(save=="yes"|save=="check"){
       write.table(distribution,file=fileSAVE,col.names=FALSE,row.names=FALSE,append=FALSE)
       return(p.value)
